import json
import logging

from . import models, app_settings

from django.contrib.auth import get_user_model
from django.contrib.auth.backends import ModelBackend

logger = logging.getLogger(__name__)

class FcBackend(ModelBackend):
    def authenticate(self, sub=None, **kwargs):
        try:
            fc_account = models.FcAccount.objects.get(sub=sub, user__is_active=True)
            msg = 'existing user {} using sub {}'.format(fc_account.user, sub)
            logger.debug(msg)
            return fc_account.user
        except models.FcAccount.DoesNotExist:
            logger.debug('user with the sub {} not existing.'.format(sub))
        if app_settings.create and 'user_info' in kwargs:
            User = get_user_model()
            user_info = kwargs['user_info']
            user = User.objects.create(
                first_name=user_info['given_name'],
                last_name=user_info['family_name'],
            )
            fc_account = models.FcAccount.objects.create(
                user=user,
                sub=sub,
                token=json.dumps(kwargs['token']))
            msg = 'user creation enabled ' \
                '(given_name : {} - family_name : {}) ' \
                'with fc_account (sub : {} - token : {})'.format(
                    user_info['given_name'],
                    user_info['family_name'],
                    sub,
                    json.dumps(kwargs['token'])
                )
            logger.debug(msg)
            return user

    def get_saml2_authn_context(self):
        import lasso
        return lasso.SAML2_AUTHN_CONTEXT_PASSWORD_PROTECTED_TRANSPORT
