import base64
import json

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings


def base64url_decode(input):
    rem = len(input) % 4
    if rem > 0:
        input += b'=' * (4 - rem)
    return base64.urlsafe_b64decode(input)


def parse_id_token(id_token):
    payload = id_token.split('.')[1]
    payload = base64url_decode(str(payload))
    return json.loads(payload)


class FcAccount(models.Model):
    user = models.ForeignKey(
        to=settings.AUTH_USER_MODEL,
        verbose_name=_('user'),
        related_name='fc_accounts')
    sub = models.TextField(
        verbose_name=_('sub'),
        db_index=True)
    token = models.TextField(verbose_name=_('access token'))
    user_info = models.TextField(verbose_name=_('access token'), blank=True, null=True)

    @property
    def id_token(self):
        return parse_id_token(self.get_token()['id_token'])

    def get_token(self):
        return json.loads(self.token)

    def get_user_info(self):
        return json.loads(self.user_info)

    def __unicode__(self):
        user_info = self.get_user_info()
        id_token = self.id_token
        display_name = []
        if 'given_name' in user_info:
            display_name.append(user_info['given_name'])
        if 'family_name' in user_info:
            display_name.append(user_info['family_name'])
        display_name = u' '.join(display_name)
        return _('{0} (Last connection from : {1})').format(display_name, id_token.get('idp'))
